.. ETFL documentation master file.

Welcome to the ETFL documentation!
==================================

ETFL is a framework to account for expression, resource allocation,
and thermodynamic constraints on stoichiometric models.

You can have a look at our preprint_ [1]_ on BiorXiv for more information on the
formulation and results on an *E. coli* model.


.. toctree::
   :numbered:
   :maxdepth: 2
   :caption: Contents:

   quickstart
   sop
   etfl

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`


.. [1] Salvy, Pierre, and Vassily Hatzimanikatis.
       "ETFL: A formulation for flux balance models accounting for expression,
       thermodynamics, and resource allocation constraints."
       bioRxiv (2019): 590992.

.. _preprint: https://www.biorxiv.org/content/10.1101/590992